@@ -4,13 +4,13 @@ import os
 
 class PREFS(object):
     """docstring for PREFS"""
-    def __init__(self, prefs, filename = "prefs", separator = "=", ender = "\n", interprete = False):
+    def __init__(self, prefs, filename = "prefs", separator = "=", ender = "\n", interpret = False):
         super(PREFS, self).__init__()
         self.prefs = prefs
         self.filename = filename
         self.separator = separator
         self.ender = ender
-        self.interprete = interprete
+        self.interpret = interpret
 
         self.ReadPrefs()
         
@@ -30,9 +30,9 @@ class PREFS(object):
 
                 for line in lines:
                     #print(line)
-                    if not self.interprete:
+                    if not self.interpret:
                         content[line.split(self.separator, 1)[0]] = line.split(self.separator, 1)[1]
-                    elif self.interprete:
+                    elif self.interpret:
                         content[line.split(self.separator, 1)[0]] = ast.literal_eval(line.split(self.separator, 1)[1])
 
             elif len(lines) == 1:
@@ -40,9 +40,9 @@ class PREFS(object):
                 line.pop()
                 for i in line:
 
-                    if not self.interprete:
+                    if not self.interpret:
                         content[i.split(self.separator, 1)[0]] = i.split(self.separator, 1)[1]
-                    elif self.interprete:
+                    elif self.interpret:
                         content[i.split(self.separator, 1)[0]] = ast.literal_eval(i.split(self.separator, 1)[1])
 
             #print(content)
@@ -78,7 +78,7 @@ class PREFS(object):
 
         self.ReadPrefs()
 
-    def ReWritePrefs(self, prefs):
+    def ReWritePrefs(self, prefs = self.prefs):
         if os.path.exists(f"{self.filename}.txt"):
             os.remove(f"{self.filename}.txt")
             self.CreatePrefs(prefs)
